WindowSizeClass class final
Represents the window size classes for a given window size, providing both a width and a height size class.
Constructors
- WindowSizeClass.calculateFromSize(Size size)
-
Creates a WindowSizeClass instance from a given Size.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightSizeClass → WindowHeightSizeClass
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthSizeClass → WindowWidthSizeClass
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited